quantizationtools.tempo_scaled_rational_to_milliseconds
=======================================================

.. autofunction:: abjad.tools.quantizationtools.tempo_scaled_rational_to_milliseconds.tempo_scaled_rational_to_milliseconds
